@@ -2,7 +2,18 @@ context("test-desc")
 
 test_that("desc works", {
   with_dir(pkg,{
-    output <-  capture_output(fill_desc(
+    output <-  capture_output(
+      fill_desc(
+        fakename, 
+        "newtitle", 
+        "Newdescription.",
+        "firstname", 
+        "lastname", 
+        "name@test.com", 
+        "http://repo_url.com"
+      )
+    )
+    add_desc <- c(
       fakename, 
       "newtitle", 
       "Newdescription.",
@@ -10,16 +21,17 @@ test_that("desc works", {
       "lastname", 
       "name@test.com", 
       "http://repo_url.com"
-    ))
-    add_desc <- c(fakename, "newtitle", "Newdescription.",
-                  "firstname", "lastname", "name@test.com", 
-                  "http://repo_url.com")
+    )
     desc <- readLines("DESCRIPTION")
     
     expect_true(
-      all(purrr::map_lgl(add_desc,function(x){any(grepl(x,desc))}))
+      all(
+        as.logical(lapply(add_desc,function(x){
+          any(grepl(x,desc))}
+        )
+      ))
     )
-      
+    
     expect_true(
       stringr::str_detect(output, "DESCRIPTION file modified")
     )
