@@ -4,7 +4,7 @@ test_that("test use_utils_ui",{
   with_dir(pkg,{
     remove_file("R/golem_utils_ui.R")
     use_utils_ui()
-    expect_true(file.exists("R/golem_utils_ui.R"))
+    expect_exists("R/golem_utils_ui.R")
   })
 })
 
@@ -12,7 +12,7 @@ test_that("test use_utils_server",{
   with_dir(pkg,{
     remove_file("R/golem_utils_server.R")
     use_utils_server()
-    expect_true(file.exists("R/golem_utils_server.R"))
+    expect_exists("R/golem_utils_server.R")
   })
 })
 
